==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/people/classes/Entity/User.php <==
<?php
namespace Claromentis\People\Entity;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_50f3d86" . "f340336b" . "e672ef20" . "f6b0f501" . "c" => base64_decode("YmxvY2tlZA=" . "="), "_4bce3a08" . "782de108b" . "3737e94bd" . "8e2956" => base64_decode("cGFzc3dvcmRfcm" . "VzZXQ="), "_21d8d15ff5e12a24e0d59a4d" . "ead984ae" => base64_decode("YXJyYXlfaW5" . "zZXJ0X2FmdG" . "Vy"), "i" . "d" => base64_decode("a" . "W" . "Q" . "="), "_7f628626dd1d55c71b1fc" . "0932ffd1d2c" => base64_decode("aXNfYXJ" . "yYXk="), "_fb165c2da46a" . "4af4ff808510c" . "1c42522" => base64_decode("bGFzdF90aW1lX3VzZW" . "Q="), "_2516886eb9700de" . "90ff5180e49aa933" . "f" => base64_decode("c3VybmFtZQ" . "=="), "_3b1c56066ee6134b4364b61" . "8bca373d6" => base64_decode("bmFtZV9kaXNwbGF" . "5"), "_7309594781df2" . "21c773926c7202" . "38ef8" => base64_decode("ZnVsbG5h" . "bWU="));
use Analogue\ORM\Entity;
use Analogue\ORM\EntityCollection;
use Claromentis\Core\ORM\Behaviors;
use Claromentis\Core\ORM\Entity\Metadata as MetadataEntity;
use Claromentis\People\Entity\Map\UserMap;
use User as LegacyUser;



























class User extends Entity
{
    use Behaviors\Casts;
    use Behaviors\Metadata;
    
    
    
    
    const AGGREGATION = 27;
    
    
    
    
    
    
    const STATUS_ACTIVE = 'yes';
    
    
    
    
    
    
    const STATUS_INACTIVE = 'no';
    
    
    
    
    
    
    protected $hidden = ['intranetuser', 'password', 'a1_hash', 'password_policy', 'pp_change_next_time', 'pp_default', 'password_last_change', 'login_frozen_time', 'login_attempts', 'login_frozen_until', 'easy_find_num', 'skin', 'default_skin', 'whats_new_list', 'notify_on_checkin', 'notification_method'];
    
    
    
    
    
    
    protected $casts = ['id' => 'int', 'intranetuser' => 'string', 'username' => 'string', 'password' => 'string', 'password_reset' => 'bool', 'a1_hash' => 'string', 'firstname' => 'string', 'surname' => 'string', 'email' => 'string', 'company' => 'string', 'extranet_id' => 'int', 'job_title' => 'string', 'last_time_login' => 'date', 'last_time_used' => 'date', 'user_code' => 'string', 'notify_on_checkin' => 'int', 'notification_method' => 'int', 'language' => 'string', 'easy_find_num' => 'int', 'skin' => 'string', 'default_skin' => 'int', 'password_policy' => 'string', 'pp_change_next_time' => 'int', 'pp_default' => 'int', 'password_last_change' => 'int', 'ldap_guid' => 'string', 'login_frozen_time' => 'date', 'login_attempts' => 'int', 'login_frozen_until' => 'int', 'whats_new_list' => 'string', 'ext_type' => 'string', 'ext_id' => 'string'];
    protected $nullable = ['company', 'job_title', 'last_time_login', 'last_time_used', 'user_code', 'default_skin', 'password_last_change', 'ldap_guid', 'whats_new_list', 'ext_type', 'ext_id'];
    protected $attributes = ['id' => 0, 'intranetuser' => 'yes', 'username' => '', 'password' => '', 'a1_hash' => '', 'firstname' => '', 'surname' => '', 'email' => '', 'company' => null, 'job_title' => null, 'last_time_login' => '0', 'last_time_used' => '0', 'user_code' => null, 'notify_on_checkin' => 1, 'notification_method' => 2, 'language' => 'en', 'easy_find_num' => 10, 'skin' => '', 'default_skin' => 0, 'password_policy' => '0_0_30_5', 'pp_change_next_time' => 0, 'pp_default' => 1, 'password_last_change' => '0', 'ldap_guid' => null, 'login_frozen_time' => '0', 'login_attempts' => 0, 'login_frozen_until' => 0, 'whats_new_list' => '', 'ext_type' => null, 'ext_id' => null, 'extranet_id' => 0];
    
    
    
    
    
    
    public function toLegacy()
    {
        $_bf131e3349c5c1596b45ed6d97a16bdd = new UserMap();
        $attributes = $_bf131e3349c5c1596b45ed6d97a16bdd->getColumnNamesFromAttributes($this->attributes);
        $_24e0e36600d6af77406a44bb618a6253 = new LegacyUser($this->id, true);
        $_24e0e36600d6af77406a44bb618a6253->LoadFromArray($attributes);
        
        
        
        if (!isset($this->metadata)) {
            $_b255ebafd5b8bb45110cd2db0604fa44 = $this->getMetadataAttribute(null);
            
            
            
            if ($_b255ebafd5b8bb45110cd2db0604fa44->elements->count() > 0) {
                foreach ($_b255ebafd5b8bb45110cd2db0604fa44->getFieldNames() as $_66dc8b21e839a9a4739443a621ecc45a) {
                    $values = $this->metadata->getValue($_66dc8b21e839a9a4739443a621ecc45a);
                    if (!$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_7f628626dd1d" . "55c71b1fc0932" . "ffd1d2c"]($values)) {
                        $values = [$values];
                    }
                    foreach ($values as $value) {
                        $_24e0e36600d6af77406a44bb618a6253->SetValue($_66dc8b21e839a9a4739443a621ecc45a, $value);
                    }
                }
            }
        }
        return $_24e0e36600d6af77406a44bb618a6253;
    }
    
    
    
    
    
    
    public function getMetadataAggregation() : int
    {
        return static::AGGREGATION;
    }
    
    
    
    
    
    
    public function getFullname() : string
    {
        return $this->getFullnameAttribute();
    }
    
    
    
    
    
    
    public function isActive() : bool
    {
        return $this->intranetuser === self::STATUS_ACTIVE;
    }
    
    
    
    
    
    
    public function isBlocked() : bool
    {
        return $this->intranetuser === self::STATUS_INACTIVE;
    }
    
    
    
    
    
    
    public function toArray()
    {
        $array = parent::toArray();
        $array = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_21d8d15" . "ff5e12a2" . "4e0d59a4" . "dead984a" . "e"]($array, $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["i" . "d"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_50f3d86f340336b" . "e672ef20f6b0f501" . "c"] => $this->isBlocked()]);
        $array = $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_21d8d15ff5e12a2" . "4e0d59a4dead984a" . "e"]($array, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_2516886eb9700de90f" . "f5180e49aa933f"], [$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_7309594781df221c77392" . "6c720238ef8"] => $this->fullname]);
        $array = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_21d8d15ff5e12a24e0" . "d59a4dead984ae"]($array, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_fb165c2da46a4af4ff80" . "8510c1c42522"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_4bce3a08782de108b3737" . "e94bd8e2956"] => $this->getPasswordResetAttribute()]);
        return $array;
    }
    
    
    
    
    
    
    public function getFullnameAttribute()
    {
        return $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_3b1c56066ee6134b4364b618bca373d" . "6"]($this->firstname, $this->surname);
    }
    
    
    
    
    
    
    public function getBlockedAttribute()
    {
        return $this->intranetuser === self::STATUS_INACTIVE;
    }
    
    
    
    
    
    
    public function setBlockedAttribute($_50f3d86f340336be672ef20f6b0f501c)
    {
        $_50f3d86f340336be672ef20f6b0f501c = (bool) $_50f3d86f340336be672ef20f6b0f501c;
        $this->intranetuser = $_50f3d86f340336be672ef20f6b0f501c ? self::STATUS_INACTIVE : self::STATUS_ACTIVE;
    }
    
    
    
    
    
    
    public function getPasswordResetAttribute() : bool
    {
        return (bool) $this->pp_change_next_time;
    }
    
    
    
    
    
    
    public function setPasswordResetAttribute(bool $_7af2f69e108c996717dac46d7412162c) : void
    {
        $this->pp_change_next_time = (int) $_7af2f69e108c996717dac46d7412162c;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/people/classes/Entity/User.php <==
<?php
namespace Claromentis\People\Entity;

$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_50f3d86f340336be672ef2" . "0f6b0f501c" => base64_decode("YmxvY2tlZA" . "=="), "_2516886eb9700de90ff5180e49aa93" . "3f" => base64_decode("c3VybmFtZQ" . "=="), "_7f628626dd1d5" . "5c71b1fc0932ff" . "d1d2c" => base64_decode("aXNfYX" . "JyYXk="), "_fb165c2da46a4af4ff8085" . "10c1c42522" => base64_decode("bGFzdF90aW1lX3Vz" . "ZWQ="), "_7309594781df22" . "1c773926c720238" . "ef8" => base64_decode("ZnVsbG" . "5hbWU="), "_3b1c56066ee6134b4364b6" . "18bca373d6" => base64_decode("bmFtZV9kaXNwbG" . "F5"), "_21d8d15ff5e12a24" . "e0d59a4dead984ae" => base64_decode("YXJyYXlfaW5zZXJ" . "0X2FmdGVy"), "i" . "d" => base64_decode("aWQ" . "="), "_4bce3a08782de" . "108b3737e94bd8" . "e2956" => base64_decode("cGFzc3dvcmRf" . "cmVzZXQ="));
use Analogue\ORM\Entity;
use Analogue\ORM\EntityCollection;
use Claromentis\Core\ORM\Behaviors;
use Claromentis\Core\ORM\Entity\Metadata as MetadataEntity;
use Claromentis\People\Entity\Map\UserMap;
use User as LegacyUser;



























class User extends Entity
{
    use Behaviors\Casts;
    use Behaviors\Metadata;
    
    
    
    
    const AGGREGATION = 27;
    
    
    
    
    
    
    const STATUS_ACTIVE = 'yes';
    
    
    
    
    
    
    const STATUS_INACTIVE = 'no';
    
    
    
    
    
    
    protected $hidden = ['intranetuser', 'password', 'a1_hash', 'password_policy', 'pp_change_next_time', 'pp_default', 'password_last_change', 'login_frozen_time', 'login_attempts', 'login_frozen_until', 'easy_find_num', 'skin', 'default_skin', 'whats_new_list', 'notify_on_checkin', 'notification_method'];
    
    
    
    
    
    
    protected $casts = ['id' => 'int', 'intranetuser' => 'string', 'username' => 'string', 'password' => 'string', 'password_reset' => 'bool', 'a1_hash' => 'string', 'firstname' => 'string', 'surname' => 'string', 'email' => 'string', 'company' => 'string', 'extranet_id' => 'int', 'job_title' => 'string', 'last_time_login' => 'date', 'last_time_used' => 'date', 'user_code' => 'string', 'notify_on_checkin' => 'int', 'notification_method' => 'int', 'language' => 'string', 'easy_find_num' => 'int', 'skin' => 'string', 'default_skin' => 'int', 'password_policy' => 'string', 'pp_change_next_time' => 'int', 'pp_default' => 'int', 'password_last_change' => 'int', 'ldap_guid' => 'string', 'login_frozen_time' => 'date', 'login_attempts' => 'int', 'login_frozen_until' => 'int', 'whats_new_list' => 'string', 'ext_type' => 'string', 'ext_id' => 'string'];
    protected $nullable = ['company', 'job_title', 'last_time_login', 'last_time_used', 'user_code', 'default_skin', 'password_last_change', 'ldap_guid', 'whats_new_list', 'ext_type', 'ext_id'];
    protected $attributes = ['id' => 0, 'intranetuser' => 'yes', 'username' => '', 'password' => '', 'a1_hash' => '', 'firstname' => '', 'surname' => '', 'email' => '', 'company' => null, 'job_title' => null, 'last_time_login' => '0', 'last_time_used' => '0', 'user_code' => null, 'notify_on_checkin' => 1, 'notification_method' => 2, 'language' => 'en', 'easy_find_num' => 10, 'skin' => '', 'default_skin' => 0, 'password_policy' => '0_0_30_5', 'pp_change_next_time' => 0, 'pp_default' => 1, 'password_last_change' => '0', 'ldap_guid' => null, 'login_frozen_time' => '0', 'login_attempts' => 0, 'login_frozen_until' => 0, 'whats_new_list' => '', 'ext_type' => null, 'ext_id' => null, 'extranet_id' => 0];
    
    
    
    
    
    
    public function toLegacy()
    {
        $_bf131e3349c5c1596b45ed6d97a16bdd = new UserMap();
        $attributes = $_bf131e3349c5c1596b45ed6d97a16bdd->getColumnNamesFromAttributes($this->attributes);
        $_24e0e36600d6af77406a44bb618a6253 = new LegacyUser($this->id, true);
        $_24e0e36600d6af77406a44bb618a6253->LoadFromArray($attributes);
        
        
        
        if (!isset($this->metadata)) {
            $_b255ebafd5b8bb45110cd2db0604fa44 = $this->getMetadataAttribute(null);
            
            
            
            if ($_b255ebafd5b8bb45110cd2db0604fa44->elements->count() > 0) {
                foreach ($_b255ebafd5b8bb45110cd2db0604fa44->getFieldNames() as $_66dc8b21e839a9a4739443a621ecc45a) {
                    $values = $this->metadata->getValue($_66dc8b21e839a9a4739443a621ecc45a);
                    if (!$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_7f628626dd1d55c71b1fc0932" . "ffd1d2c"]($values)) {
                        $values = [$values];
                    }
                    foreach ($values as $value) {
                        $_24e0e36600d6af77406a44bb618a6253->SetValue($_66dc8b21e839a9a4739443a621ecc45a, $value);
                    }
                }
            }
        }
        return $_24e0e36600d6af77406a44bb618a6253;
    }
    
    
    
    
    
    
    public function getMetadataAggregation() : int
    {
        return static::AGGREGATION;
    }
    
    
    
    
    
    
    public function getFullname() : string
    {
        return $this->getFullnameAttribute();
    }
    
    
    
    
    
    
    public function isActive() : bool
    {
        return $this->intranetuser === self::STATUS_ACTIVE;
    }
    
    
    
    
    
    
    public function isBlocked() : bool
    {
        return $this->intranetuser === self::STATUS_INACTIVE;
    }
    
    
    
    
    
    
    public function toArray()
    {
        $_fd62bc4eaaf7d58dea9bada3e30443b9 = parent::toArray();
        $_fd62bc4eaaf7d58dea9bada3e30443b9 = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_21d8d15ff5e12a24e0d59" . "a4dead984ae"]($_fd62bc4eaaf7d58dea9bada3e30443b9, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["i" . "d"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_50f3d86f3403" . "36be672ef20f6" . "b0f501c"] => $this->isBlocked()]);
        $_fd62bc4eaaf7d58dea9bada3e30443b9 = $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_21d8d15ff5e12a24e0d" . "59a4dead984ae"]($_fd62bc4eaaf7d58dea9bada3e30443b9, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_2516886eb9700" . "de90ff5180e49a" . "a933f"], [$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_7309594" . "781df221" . "c773926c" . "720238ef" . "8"] => $this->fullname]);
        $_fd62bc4eaaf7d58dea9bada3e30443b9 = $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_21d8d15f" . "f5e12a24e" . "0d59a4dea" . "d984ae"]($_fd62bc4eaaf7d58dea9bada3e30443b9, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_fb165c2da46a4" . "af4ff808510c1c" . "42522"], [$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_4bce3a08782de108b3737e94bd" . "8e2956"] => $this->getPasswordResetAttribute()]);
        return $_fd62bc4eaaf7d58dea9bada3e30443b9;
    }
    
    
    
    
    
    
    public function getFullnameAttribute()
    {
        return $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_3b1c56066ee6134" . "b4364b618bca373d" . "6"]($this->firstname, $this->surname);
    }
    
    
    
    
    
    
    public function getBlockedAttribute()
    {
        return $this->intranetuser === self::STATUS_INACTIVE;
    }
    
    
    
    
    
    
    public function setBlockedAttribute($_50f3d86f340336be672ef20f6b0f501c)
    {
        $_50f3d86f340336be672ef20f6b0f501c = (bool) $_50f3d86f340336be672ef20f6b0f501c;
        $this->intranetuser = $_50f3d86f340336be672ef20f6b0f501c ? self::STATUS_INACTIVE : self::STATUS_ACTIVE;
    }
    
    
    
    
    
    
    public function getPasswordResetAttribute() : bool
    {
        return (bool) $this->pp_change_next_time;
    }
    
    
    
    
    
    
    public function setPasswordResetAttribute(bool $_7af2f69e108c996717dac46d7412162c) : void
    {
        $this->pp_change_next_time = (int) $_7af2f69e108c996717dac46d7412162c;
    }
}
